==> wtp-sdk-R-2.0-200706260303.zip: org/eclipse/jst/jsf/facesconfig/ui/wizard/WizardMessages.java <==
/*******************************************************************************
 * Copyright (c) 2001, 2006 Oracle Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Oracle Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jst.jsf.facesconfig.ui.wizard;

import org.eclipse.osgi.util.NLS;

public final class WizardMessages extends NLS {

	private static final String BUNDLE_NAME = "org.eclipse.jst.jsf.facesconfig.ui.wizard.WizardMessages";

	private WizardMessages() {
		// Do not instantiate
	}

	static {
		NLS.initializeMessages(BUNDLE_NAME, WizardMessages.class);
	}

	public static String NewManagedBeanWizardBase_Type;

	public static String NewManagedBeanWizardBase_Description;

	public static String NewManagedBeanWizardBase_Title;

	public static String NewManagedBeanCreationWizard_Title;

	public static String IntroWizardPage_Title;

	public static String IntroWizardPage_Intro;

	public static String ManagedBeanWizardSelectionPage_Title;

	public static String ManagedBeanWizardSelectionPage_Description;

	public static String ManagedBeanWizardSelectionPage_Group;

	public static String ManagedBeanWizardSelectionPage_HelpContextID;

	public static String Registry_LoadWizard_Error;

	public static String NewWizard_Title_WizardDefault;

	public static String ManagedBeanPropertyWizardPage_Title;

	public static String ManagedBeanPropertyWizardPage_Description;

	public static String ManagedBeanPropertyWizardPage_General;

	public static String ManagedBeanPropertyWizardPage_ManagedBeanName;

	public static String ManagedBeanPropertyWizardPage_ManagedBeanScope;

	public static String ManagedBeanPropertyWizardPage_ManagedBeanDescription;

	public static String ManagedBeanPropertyWizardPage_ManagedBeanProperty;

	public static String ManagedBeanPropertyWizardPage_PropertyName;

	public static String ManagedBeanPropertyWizardPage_Type;

	public static String ManagedBeanPropertyWizardPage_Value;

	public static String ManagedBeanPropertyWizardPage_Button_Add;

	public static String ManagedBeanPropertyWizardPage_Button_Edit;

	public static String ManagedBeanPropertyWizardPage_Button_Remove;

	public static String ManagedBeanPropertyWizardPage_Warning_MissingManagedBeanName;

	public static String ManagedBeanPropertyWizardPage_Warning_InvalidManagedBeanName;

	public static String ManagedBeanPropertyWizardPage_Warning_DuplicateManagedBeanName;

	public static String ManagedBeanPropertyEditDialog_PropertyName;

	public static String ManagedBeanPropertyEditDialog_DataType;

	public static String ManagedBeanPropertyEditDialog_InitialValue;

	public static String ManagedBeanPropertyEditDialog_Title_NewPropertyEntry;

	public static String ManagedBeanPropertyEditDialog_Title_ExistingPropertyEntry;

	public static String FacesConfigSelectionWizardPage_Title;

	public static String FacesConfigSelectionWizardPage_Description;

	public static String FacesConfigSelectionWizardPage_Project;

	public static String FacesConfigSelectionWizardPage_FacesConfig;

	public static String FacesConfigSelectionWizardPage_FacesConfig_Browser;

	public static String FacesConfigSelectionWizardPage_Warning_MissingProjectName;

	public static String FacesConfigSelectionWizardPage_Warning_MissingFacesConfigName;

	public static String FacesConfigSelectionWizardPage_Warning_InvalidFacesConfigName;

	public static String FacesConfigSelectionWizardPage_Warning_InvalidFacesConfigContent;

	public static String FacesConfigSelectionWizardPage_Warning_FacesConfigNotDefinedInWebDotXML;

	public static String FacesConfigSelectionWizardPage_HelpContextID;

	public static String FacesConfigFileSelectionDialog_Title;

	public static String FacesConfigFileSelectionDialog_Description;

	public static String JavaSelectionWizardPage_Title;

	public static String JavaSelectionWizardPage_Description;

	public static String JavaSelectionWizardPage_Group;

	public static String JavaSelectionWizardPage_Search;

	public static String JavaSelectionWizardPage_Search_Description;

	public static String JavaSelectionWizardPage_Search_ClassName;

	public static String JavaSelectionWizardPage_Search_ClassName_Browse;

	public static String JavaSelectionWizardPage_Create;

	public static String JavaSelectionWizardPage_Create_Description;

	public static String JavaSelectionWizardPage_FindType;

	public static String JavaSelectionWizardPage_FindType_Filter;

	public static String JavaSelectionWizardPage_Error_ClassIsEmpty;

	public static String JavaSelectionWizardPage_Error_ClassIsNotDefined;

	public static String JavaSelectionWizardPage_HelpContextID;

	public static String NewJavaManagedBeanWizard_Summary_ProjectName;

	public static String NewJavaManagedBeanWizard_Summary_FacesConfigFileName;

	public static String NewJavaManagedBeanWizard_Summary_TypeName;

	public static String NewJavaManagedBeanWizard_Summary_PackageName;

	public static String NewJavaManagedBeanWizard_Summary_SourceFolder;

	public static String NewJavaManagedBeanWizard_Summary_ManagedBeanName;

	public static String NewJavaManagedBeanWizard_Summary_ManagedBeanScope;

	public static String NewJavaManagedBeanWizard_Summary_ClassName;

	public static String NewJavaManagedBeanWizard_Summary_Description;

	public static String NewJavaManagedBeanWizard_SummaryPage_Description;

	public static String NewJavaManagedBeanWizard_Task_CreateNewManagedBean;

	public static String NewJavaManagedBeanWizard_Task_CreateNewJavaClass;

	public static String DuplicateBeanWizard_Title;

	public static String DuplicateBeanPage_Title;

	public static String DuplicateBeanPage_Description;

	public static String DuplicateBeanGroup_Group_Label;

	public static String DuplicateBeanGroup_OverwriteButton_Text;

	public static String DuplicateBeanGroup_NewButton_Text;

	public static String DuplicateBeanGroup_NewNameDialogField_Label;

	public static String DuplicateBeanGroup_Error_EmptyManagedBeanName;

	public static String DuplicateBeanGroup_Error_InvalidManagedBeanName;

	public static String DuplicateBeanGroup_Error_DuplicatedManagedBeanName;

	public static String WizardSummaryPage_Title_WizardSummary;

	public static String WizardSummaryPage_Summary_SummaryDesc;

	public static String WizardSummaryPage_Label_Field;

	public static String WizardSummaryPage_Label_Value;

}

==> wtp-sdk-R-3.0-20080616152118a.zip: org/eclipse/jst/jsf/facesconfig/ui/wizard/WizardMessages.java <==
/*******************************************************************************
 * Copyright (c) 2001, 2007 Oracle Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Oracle Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.jst.jsf.facesconfig.ui.wizard;

import org.eclipse.osgi.util.NLS;

/**
 * Message bundle for wizards
 *
 */
public final class WizardMessages extends NLS {

	private static final String BUNDLE_NAME = "org.eclipse.jst.jsf.facesconfig.ui.wizard.WizardMessages";

	private WizardMessages() {
		// Do not instantiate
	}

	static {
		NLS.initializeMessages(BUNDLE_NAME, WizardMessages.class);
	}

	/**
	 * see WizardMessages.properties
	 */
	public static String NewManagedBeanWizardBase_Type;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewManagedBeanWizardBase_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewManagedBeanWizardBase_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewManagedBeanCreationWizard_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String IntroWizardPage_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String IntroWizardPage_Intro;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanWizardSelectionPage_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanWizardSelectionPage_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanWizardSelectionPage_Group;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanWizardSelectionPage_HelpContextID;

	/**
	 * see WizardMessages.properties
	 */
	public static String Registry_LoadWizard_Error;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewWizard_Title_WizardDefault;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_General;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_ManagedBeanName;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_ManagedBeanScope;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_ManagedBeanDescription;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_ManagedBeanProperty;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_PropertyName;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Type;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Value;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Button_Add;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Button_Edit;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Button_Remove;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Warning_MissingManagedBeanName;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Warning_InvalidManagedBeanName;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyWizardPage_Warning_DuplicateManagedBeanName;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyEditDialog_PropertyName;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyEditDialog_DataType;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyEditDialog_InitialValue;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyEditDialog_Title_NewPropertyEntry;

	/**
	 * see WizardMessages.properties
	 */
	public static String ManagedBeanPropertyEditDialog_Title_ExistingPropertyEntry;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_Project;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_FacesConfig;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_FacesConfig_Browser;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_Warning_MissingProjectName;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_Warning_MissingFacesConfigName;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_Warning_InvalidFacesConfigName;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_Warning_InvalidFacesConfigContent;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_Warning_FacesConfigNotDefinedInWebDotXML;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigSelectionWizardPage_HelpContextID;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigFileSelectionDialog_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String FacesConfigFileSelectionDialog_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Group;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Search;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Search_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Search_ClassName;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Search_ClassName_Browse;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Create;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Create_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_FindType;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_FindType_Filter;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Error_ClassIsEmpty;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_Error_ClassIsNotDefined;

	/**
	 * see WizardMessages.properties
	 */
	public static String JavaSelectionWizardPage_HelpContextID;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_ProjectName;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_FacesConfigFileName;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_TypeName;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_PackageName;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_SourceFolder;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_ManagedBeanName;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_ManagedBeanScope;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_ClassName;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Summary_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_SummaryPage_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Task_CreateNewManagedBean;

	/**
	 * see WizardMessages.properties
	 */
	public static String NewJavaManagedBeanWizard_Task_CreateNewJavaClass;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanWizard_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanPage_Title;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanPage_Description;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanGroup_Group_Label;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanGroup_OverwriteButton_Text;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanGroup_NewButton_Text;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanGroup_NewNameDialogField_Label;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanGroup_Error_EmptyManagedBeanName;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanGroup_Error_InvalidManagedBeanName;

	/**
	 * see WizardMessages.properties
	 */
	public static String DuplicateBeanGroup_Error_DuplicatedManagedBeanName;

	/**
	 * see WizardMessages.properties
	 */
	public static String WizardSummaryPage_Title_WizardSummary;

	/**
	 * see WizardMessages.properties
	 */
	public static String WizardSummaryPage_Summary_SummaryDesc;

	/**
	 * see WizardMessages.properties
	 */
	public static String WizardSummaryPage_Label_Field;

	/**
	 * see WizardMessages.properties
	 */
	public static String WizardSummaryPage_Label_Value;

}
